# Headless CMS - Notify

## Contents of this file

- [Introduction](#introduction)
- [Requirements](#requirements)
- [Installation](#installation)
- [Configuration](#configuration)
- [Extending](#extending)

## Introduction

This submodule provides notification functionality for decoupled/headless
Drupal CMS setups, allowing real-time notifications when e.g. content is
created, updated, or deleted. These notifications can be consumed by external
applications to trigger actions or update their content cache.

### Key Features

- Support for multiple notification events
  - Entity Operations (create, update, delete)
  - Cache Rebuild
- Allows sending custom notify messages
- Transport Plugin System to support multiple ways to send notifications
- Deeply integrates with the [Consumers](https://www.drupal.org/project/consumers)
  module to allow configuring notification settings on a per consumer basis.
- By default, notifications are not sent during migrations (requires the
  [Migrate Utils](https://www.drupal.org/project/migrate_utils) module).

The following submodules extend the functionality of this module:

|Submodule|Description|
|---|---|
|[Notify - Webhook](modules/headless_cms_notify_webhook)|Provides a transport to send notify messages via webhook requests.|
|[Notify - NATS](modules/headless_cms_notify_nats)|Provides a transport to publish notify messages to a NATS server.|

See the README.md files in the submodules for more information.

## Requirements

The module requires Drupal 10.3 or 11 and the following:

- Headless CMS (parent module)
- [Consumers](https://www.drupal.org/project/consumers)

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

Configuration is done in the consumer settings.

Notification transports can be managed at
`/admin/config/headless-cms/notify/transports`.

### Migrations

By default, notifications are not sent during migrations. This can be changed
by setting the `headless_cms_notify.enable_notify_on_migrate` state to `true`.

> **Note:** This requires the [Migrate Utils](https://www.drupal.org/project/migrate_utils)
> module to be installed!

```bash
drush state:set headless_cms_notify.enable_notify_on_migrate true
```

## Extending

Several aspects of the module's functionality can be extended.

### Custom Transport

To implement a custom transport, create a plugin that:

- Has the `HeadlessNotifyTransport` attribute
- Extends the `HeadlessNotifyTransportBase` class

If the transport requires configuration, implement the
`HeadlessNotifyTransportPluginFormInterface` interface.

Place the plugin in the `src/Plugin/HeadlessNotifyTransport` directory of
your module.

For specific examples, see the implementations of the built-in transports in the
respective submodules.

### Custom Notify Message

To send notify messages of a custom type, a custom notify message can be easily
created. To achieve that do:

- Create a new class in `src/NotifyMessage` of your module
- Extend the `HeadlessNotifyMessage` class

**It is important that the class is placed in `src/NotifyMessage` in order to be
discovered by the `HeadlessNotifyMessageDiscoveryService`!**

A message can then be sent via the `HeadlessNotifyService` using the
`HeadlessNotifyService::sendNotifyMessage()` method.
