<?php

declare(strict_types=1);

namespace Drupal\headless_cms_notify\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Provides a form for Headless CMS Notify settings.
 */
class HeadlessCmsNotifySettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
      $container->get('config.typed'),
    );
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames() {
    return [
      'headless_cms_notify.settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'headless_cms_notify_settings';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form = parent::buildForm($form, $form_state);

    $form['no_configuration'] = [
      '#type' => 'markup',
      '#markup' => $this->t('Configuration of this module is done in the <a href=":url">consumer settings</a>.', [':url' => Url::fromRoute('entity.consumer.collection')->toString()]),
    ];

    return $form;
  }

}
