# Headless CMS - Preview

## Contents of this file

- [Introduction](#introduction)
- [Requirements](#requirements)
- [Installation](#installation)
- [Configuration](#configuration)

## Introduction

This submodule provides preview functionality for decoupled/headless Drupal CMS
setups, allowing content editors to preview content before publishing while
using an external frontend application.

Integrates with Node Preview, Node Revisions and Content Moderation.

### For what is this for?

When running Drupal as a headless CMS with a decoupled frontend
(like React, Vue, etc.), content editors still need to preview their content
changes before publishing. This module bridges that gap by providing a secure
preview system that works with your external frontend.

The module generates secure preview URLs that can be used to view unpublished
content or pending changes in your frontend application, while maintaining
Drupal's access control and security.

### Functionality

The following functionality is provided:

- Implements a new route for the JSON:API to get the preview data of a node.
- Implements a special headless CMS preview token that authorizes a request to
  access the preview and revision data of a node, which is by default scoped to
  the user that saved the node preview.
- Fixes JSON:API includes for preview and revision requests.
- Adds a new "Save Preview" button on the node create/edit form to save the node
  preview data, while staying on the same page.
- When a preview is saved, links to the frontend application are displayed in
  the node form.
- Adds operations on the node revision overview page to access this revision
  data from the frontend application.
- Deeply integrates with the [Consumers](https://www.drupal.org/project/consumers)
  module to allow setting a preview / revision URL on a per consumer basis.

The following submodules extend the functionality of this module:

|Submodule|Description|
|---|---|
|[Preview - NATS](modules/headless_cms_preview_nats)|Allows publish preview updates to a NATS server.|

See the README.md files in the submodules for more information.

## Requirements

The core module requires Drupal 10.3 or 11 and the following contrib modules:

- [Consumers](https://www.drupal.org/project/consumers)

### Patches

The following drupal core patches are required, if the changes have not yet been
merged into drupal core:

- [Issue #3088239 - Fix JSON:API include relation revisions](https://www.drupal.org/project/drupal/issues/3088239)

## Installation

Install as you would normally install a contributed Drupal module. For further
information, see
[Installing Drupal Modules](https://www.drupal.org/docs/extending-drupal/installing-drupal-modules).

## Configuration

Configuration is done on the settings page of the headless CMS module at
`/admin/config/headless-cms/preview`
