<?php

/**
 * @file
 * Basefields.
 */

declare(strict_types=1);

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Core\StringTranslation\TranslatableMarkup;

/**
 * Defines basefields for the consumer entity.
 *
 * Adds fields for preview and revision URLs.
 */
function headless_cms_preview_consumer_basefields_01(): array {
  $fields = [];

  $fields['headless_cms_preview_url'] = BaseFieldDefinition::create('string')
    ->setLabel(new TranslatableMarkup('Preview URL'))
    ->setDescription(new TranslatableMarkup('URL to display the preview of a node entity in the frontend of this consumer. Supports the following placeholders: [preview:entity_type_id], [preview:entity_bundle], [preview:entity_uuid], [preview:owner_id], [preview:token]'))
    ->setDisplayOptions('view', [
      'label' => 'inline',
      'weight' => 6,
    ])
    ->setDisplayOptions('form', [
      'type' => 'string_textfield',
      'weight' => 6,
    ])
    ->setRevisionable(TRUE)
    ->setTranslatable(FALSE)
    ->setRequired(FALSE)
    ->setDefaultValue(FALSE);

  $fields['headless_cms_revision_url'] = BaseFieldDefinition::create('string')
    ->setLabel(new TranslatableMarkup('Revision URL'))
    ->setDescription(new TranslatableMarkup('URL to display a particular revision of a node entity in the frontend of this consumer. Supports the following placeholders: [preview:entity_type_id], [preview:entity_bundle], [preview:entity_uuid], [preview:revision_id], [preview:owner_id], [preview:token]'))
    ->setDisplayOptions('view', [
      'label' => 'inline',
      'weight' => 6,
    ])
    ->setDisplayOptions('form', [
      'type' => 'string_textfield',
      'weight' => 6,
    ])
    ->setRevisionable(TRUE)
    ->setTranslatable(FALSE)
    ->setRequired(FALSE)
    ->setDefaultValue(FALSE);

  return $fields;
}
